@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2017 openpyxl
 
 """Read an xlsx file into Python"""
 
@@ -27,13 +27,14 @@ from openpyxl.xml.constants import (
     ARC_CORE,
     ARC_CONTENT_TYPES,
     ARC_WORKBOOK,
-    ARC_WORKBOOK_RELS,
     ARC_THEME,
     COMMENTS_NS,
     SHARED_STRINGS,
     EXTERNAL_LINK,
     XLTM,
     XLTX,
+    XLSM,
+    XLSX,
 )
 
 from openpyxl.comments.comment_sheet import CommentSheet
@@ -43,11 +44,13 @@ from .strings import read_string_table
 from openpyxl.styles.stylesheet import apply_stylesheet
 
 from openpyxl.packaging.core import DocumentProperties
-from openpyxl.packaging.manifest import Manifest
+from openpyxl.packaging.manifest import Manifest, Override
 from openpyxl.packaging.workbook import WorkbookParser
 from openpyxl.packaging.relationship import get_dependents, get_rels_path
 
 from openpyxl.worksheet.read_only import ReadOnlyWorksheet
+from openpyxl.worksheet.table import Table
+
 from openpyxl.xml.functions import fromstring
 
 from .worksheet import WorkSheetParser
@@ -119,6 +122,22 @@ def _validate_archive(filename):
     return archive
 
 
+def _find_workbook_part(package):
+    workbook_types = [XLTM, XLTX, XLSM, XLSX]
+    for ct in workbook_types:
+        part = package.find(ct)
+        if part:
+            return part
+
+    # some applications reassign the default for application/xml
+    defaults = set((p.ContentType for p in package.Default))
+    workbook_type = defaults & set(workbook_types)
+    if workbook_type:
+        return Override("/" + ARC_WORKBOOK, workbook_type.pop())
+
+    raise IOError("File contains no valid workbook part")
+
+
 def load_workbook(filename, read_only=False, keep_vba=KEEP_VBA,
                   data_only=False, guess_types=False, keep_links=True):
     """Open the given filename and return the workbook
@@ -152,12 +171,18 @@ def load_workbook(filename, read_only=False, keep_vba=KEEP_VBA,
     archive = _validate_archive(filename)
     read_only = read_only
 
-    parser = WorkbookParser(archive)
+    src = archive.read(ARC_CONTENT_TYPES)
+    root = fromstring(src)
+    package = Manifest.from_tree(root)
+
+    wb_part = _find_workbook_part(package)
+    parser = WorkbookParser(archive, wb_part.PartName[1:])
     wb = parser.wb
     wb._data_only = data_only
     wb._read_only = read_only
     wb._keep_links = keep_links
     wb.guess_types = guess_types
+    wb.template = wb_part.ContentType in (XLTX, XLTM)
     parser.parse()
     wb._sheets = []
 
@@ -182,11 +207,6 @@ def load_workbook(filename, read_only=False, keep_vba=KEEP_VBA,
         src = fromstring(archive.read(ARC_CORE))
         wb.properties = DocumentProperties.from_tree(src)
 
-    # is workbook a template or note
-    src = archive.read(ARC_CONTENT_TYPES)
-    root = fromstring(src)
-    package = Manifest.from_tree(root)
-    wb.template = XLTX in package or XLTM in package
 
     shared_strings = []
     ct = package.find(SHARED_STRINGS)
@@ -239,12 +259,18 @@ def load_workbook(filename, read_only=False, keep_vba=KEEP_VBA,
                     ):
                     ws.legacy_drawing = rels[ws.legacy_drawing].target
 
+                for t in ws_parser.tables:
+                    src = archive.read(t)
+                    xml = fromstring(src)
+                    table = Table.from_tree(xml)
+                    ws.add_table(table)
+
         ws.sheet_state = sheet.state
         ws._rels = [] # reset
 
     parser.assign_names()
 
-    wb._differential_styles.styles =  []
+    #wb._differential_styles.styles =  [] # tables may depened upon dxf
 
     archive.close()
     return wb
